import numpy as np


__title__ = "pandas-refract"
__version__ = "1.2.0"
__author__ = "Nicholas Lawrence"
__license__ = "MIT"
__copyright__ = "Copyright 2018-2019 Nicholas Lawrence"


def refract(df, conditional, reset_index=True):
    """

    Return pair of Dataframes split against Truthy and Falseyness of provided array. Option to reset index in place.

    / >>> data = {'temperature': ['high', 'low', 'low', 'high'],
                  'overcast': [True, False, True, False]
                  }

    / >>> df = pandas.DataFrame(data)

    / >>> hot_df, cold_df = refract(df, df.temperature == 'high')

    / >>> overcast_df, not_overcast_df = refract(df, df.overcast, reset_index=True)

    / >>> print(overcast_df.iloc[0], not_overcast_df.iloc[0])

    """
    _conditional = np.asarray(conditional, bool)
    _true_df = df[_conditional]
    _false_df = df[~_conditional]

    if reset_index:
        _true_df = _true_df.reset_index(drop=True)
        _false_df = _false_df.reset_index(drop=True)

    return _true_df, _false_df


def disperse(df, label, reset_index=True):
    """

    Return dictionary where key is a unique value in given dataframe series and value is dataframe where given column is
    key value.

    / >>> data = {'temperature': ['high', 'low', 'low', 'high', 'medium', 'medium'],
                  'overcast'   : [True, False, True, False, False, True]
                  }

    / >>> df = pd.DataFrame(data)

    / >>> prism = disperse(df, 'temperature')

    / >>> {'high':   temperature  overcast
                    0      high      True
                    1      high     False,

           'low':   temperature  overcast
                    0       low     False
                    1       low      True,

           'medium':   temperature  overcast
                    0    medium     False
                    1    medium      True
          }

    """
    _notnulls, _nulls = refract(df, df[label].notnull())

    _prism = {k: df[df[label] == k] for k in set(_notnulls[label])}
    _prism['null'] = _nulls

    if reset_index:
        return {k: v.reset_index(drop=True) for k, v in _prism.items()}

    return _prism




from setuptools import setup

import pandas_refract
import sys


if sys.version_info[0] >= 3:
    openf = open
else:
    import codecs

    openf = codecs.open


def read(fn):
    with openf(fn, encoding="utf-8") as fp:
        return fp.read()


setup(
    name="pandas_refract",
    version=pandas_refract.__version__,
    description="Split a dataframe by boolean array",
    long_description=(read("README.rst")),
    url="http://github.com/kdggavkc/pandas-refract/",
    license=pandas_refract.__license__,
    author=pandas_refract.__author__,
    author_email="nickclawrence@gmail.com",
    py_modules=["pandas_refract"],
    install_requires=[
        'numpy'
    ],
    classifiers=[
        "Intended Audience :: Developers",
        "Natural Language :: English",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3.6",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
)
